Installation
============

Invenio-Classifier is available on PyPi:


.. code-block:: shell

    pip install "invenio-classifier>=1.0.0"


Configuration
=============

.. automodule:: invenio_classifier.config
   :members:
   :undoc-members:
